/*
 * compile with:
 * gcc vfsinfo.c -o vfsinfo `pkg-config --libs --cflags gnome-vfs-2.0`
 *
 * run as ./vfsinfo <uri>
 *
 * Have fun
 *
 * Bastien Nocera <hadess@hadess.net>
 */


#include <libgnomevfs/gnome-vfs.h>

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>

static void
show_result (GnomeVFSResult result, const gchar *what, const gchar *text_uri)
{
	fprintf (stderr, "%s `%s': %s\n",
		 what, text_uri, gnome_vfs_result_to_string (result));
	if (result != GNOME_VFS_OK)
		exit (1);
}

static void
show_file_info (GnomeVFSFileInfo *info)
{
	g_print ("name: %s mime-type: %s size: %"GNOME_VFS_SIZE_FORMAT_STR"\n",
			info->name, info->mime_type, info->size);
}

int
main (int argc, char **argv)
{
	GnomeVFSResult    result;
	GnomeVFSFileInfo *info;

	if (argc != 2) {
		printf ("Usage: %s <uri>\n", argv[0]);
		return 1;
	}

	if (! gnome_vfs_init ()) {
		fprintf (stderr, "Cannot initialize gnome-vfs.\n");
		return 1;
	}

	info = gnome_vfs_file_info_new ();
	result = gnome_vfs_get_file_info (argv[1], info, 0);
	if (result == GNOME_VFS_OK) 
		show_file_info (info);
	else
		show_result(result, argv[1], "boh");

	return 0;
}
