// gcc -o vfsmkdir vfsmkdir.c `pkg-config --libs --cflags gnome-vfs-2.0`

#include <libgnomevfs/gnome-vfs.h>

#define DEBUG
#ifdef DEBUG
#define D(x...) g_message (x)
#else
#define D(x...) 
#endif

static GnomeVFSResult
gnome_vfs_make_directory_with_parents_for_uri (GnomeVFSURI * uri,
					       guint perm)
{
	GnomeVFSResult result;
	GnomeVFSURI *parent, *work_uri;
	GList *list = NULL;

	result = gnome_vfs_make_directory_for_uri (uri, perm);
	if (result == GNOME_VFS_OK || result != GNOME_VFS_ERROR_NOT_FOUND)
		return result;

	work_uri = uri;

	while (result == GNOME_VFS_ERROR_NOT_FOUND) {
		parent = gnome_vfs_uri_get_parent (work_uri);
		D("trying to create: %s", gnome_vfs_uri_to_string (parent, 0));
		result = gnome_vfs_make_directory_for_uri (parent, perm);

		if (result == GNOME_VFS_ERROR_NOT_FOUND)
			list = g_list_prepend (list, parent);
		work_uri = parent;
	}

	if (result != GNOME_VFS_OK) {
		/* Clean up */
		while (list != NULL) {
			gnome_vfs_uri_unref ((GnomeVFSURI *) list->data);
			list = g_list_remove (list, list->data);
		}
	}

	while (result == GNOME_VFS_OK && list != NULL) {
		D("creating: %s", gnome_vfs_uri_to_string (list->data, 0));
		result = gnome_vfs_make_directory_for_uri
		    ((GnomeVFSURI *) list->data, perm);

		gnome_vfs_uri_unref ((GnomeVFSURI *) list->data);
		list = g_list_remove (list, list->data);
	}

	result = gnome_vfs_make_directory_for_uri (uri, perm);
	return result;
}

static GnomeVFSResult
gnome_vfs_make_directory_with_parents (const gchar * text_uri, guint perm)
{
	GnomeVFSURI *uri;
	GnomeVFSResult result;

	D("gnome_vfs_make_directory_with_parents (%s)", text_uri);
	uri = gnome_vfs_uri_new (text_uri);
	result = gnome_vfs_make_directory_with_parents_for_uri (uri, perm);
	D ("gnome_vfs_make_directory_with_parents: %s\n",
			gnome_vfs_result_to_string (result));
	gnome_vfs_uri_unref (uri);

	return result;
}

int
main (int argc, char *argv[])
{
	GList *dlist = NULL;
	gchar *directory;
	GnomeVFSResult result;

	gnome_vfs_init ();

	if (argc > 1) {
		directory = argv[1];
	} else {
		g_print ("should be %s <dir>\n", argv[0]);
		exit (0);
	}

	// result = gnome_vfs_make_directory (argv[1],
	result = gnome_vfs_make_directory_with_parents (argv[1],
			GNOME_VFS_PERM_USER_ALL
			| GNOME_VFS_PERM_GROUP_ALL
			| GNOME_VFS_PERM_OTHER_READ);

	if (result != GNOME_VFS_OK) {
		g_print ("Error: %s\n",
			 gnome_vfs_result_to_string (result));
		exit (0);
	}

	gnome_vfs_shutdown ();
	return 0;
}
